'*** File Details *****************************************************************
'    File        : HercNet.vb
'    Requires    : None
'    Type        : VB.NET Class
'    Description : Implements the Hercules DJ Console for VB.NET, 
'                  thanks to Greg Ellis!
'
' HERC.DLL Copyright  2005 Greg Ellis. All rights reserved.
' VB.NET Interface Copyright  2006 ActiveASP Software. All rights reserved.
'
' Send improvements, updates, questions to biggun@wi.rr.com
'
'--- Change Log   -----------------------------------------------------------------
'    4/5/2006 by Rick (Big_Gun) - Initial Creation
'**********************************************************************************

Namespace Hercules.DJConsole

    Public Class HercNet

#Region " Public Enumerations "

        Public Enum HercErrorCodes As Integer
            HERC_OK = 0   ' all is OK
            HERC_ERROR_INIT = 1 ' Hercules DJ Console is not initialized
            HERC_ERROR_PORT = 2 ' can't open midi port
            HERC_ERROR_THREAD = 3 ' can't start midi event thread
            HERC_ERROR_DEVICE = 4 ' can't find a valid Hercules DJ Console
        End Enum

        'Console Types
        Public Enum HercConsoleTypes As Integer
            HERC_CONSOLE = 3000  'try to initialize regular herc console
            HERC_CONSOLE_MK2 = 3001 'try to initialize mk2 herc console
            HERC_CONSOLE_MP3 = 3002 'try to initialize control mp3 console
            HERC_CONSOLE_ALL = 3004 'initialize first hercules console it finds
        End Enum

        'LED
        Public Enum HercLedType As Integer
            HERC_LED_PLAY = 2000
            HERC_LED_CUE = 2001
            HERC_LED_AUTOBEAT = 2002
            HERC_LED_MONITOR = 2003
            HERC_LED_MASTERTEMPO = 2004
            HERC_LED_LOOPFX = 2005
            HERC_LED_CUEFX = 2006
            HERC_LED_FX = 2007
            HERC_LED_FLASHPLAY = 2008
            HERC_LED_FLASHCUE = 2009
        End Enum

        Public Enum HercDeck As Integer
            HERC_DECK_A = 0
            HERC_DECK_B = 1
        End Enum

        Public Enum HercAction As Integer
            'RIGHT / LEFT
            HERC_MODE = 1000
            HERC_PLAY = 1001
            HERC_CUE = 1002
            HERC_AUTOBEAT = 1003
            HERC_TRACKPREV = 1004
            HERC_TRACKNEXT = 1005
            HERC_THREE = 1006
            HERC_TWO = 1007
            HERC_ONE = 1008
            HERC_PITCHBEND_UP = 1009
            HERC_PITCHBEND_DOWN = 1010
            HERC_PREVIEW = 1011
            HERC_MASTERTEMPO = 1012
            HERC_MOUSEBUTTON = 1013
            HERC_BASS = 1014
            HERC_MEDIUM = 1015
            HERC_TREBLE = 1016
            HERC_PITCH = 1017
            HERC_VOLUME = 1018
            HERC_JOGWHEEL = 1019
            HERC_SELECTFX = 1023

            'BOTH
            HERC_CROSSFADER = 1020
            HERC_JOYSTICK_HOR = 1021
            HERC_JOYSTICK_VER = 1022
        End Enum

#End Region

#Region " Public Delegations "

        Public Delegate Sub HercEventCallbackHandler(ByVal dwAction As Hercules.DJConsole.HercNet.HercAction, ByVal dwValue As Integer, ByVal userInstance As Integer)

#End Region

#Region " Public Methods "

        Public Declare Function HERC_ErrorGetCode Lib "HERC.dll" () As HercErrorCodes

        Public Declare Function HERC_Init Lib "HERC.dll" (ByVal dwConsoleType As HercConsoleTypes) As Boolean
        Public Declare Function HERC_Init Lib "HERC.dll" (ByVal dwConsoleType As HercConsoleTypes, ByVal hWnd As System.IntPtr) As Boolean

        Public Declare Function HERC_Free Lib "HERC.dll" () As Boolean

        Public Declare Function HERC_SetLED Lib "HERC.dll" (ByVal dwDeckID As HercDeck, ByVal dwLEDCode As HercLedType, ByVal bOn As Boolean) As Boolean

        Public Declare Function HERC_EventCallbackSet Lib "HERC.dll" (ByVal HERCPROC_DeckA As HercEventCallbackHandler, ByVal HERCPROC_DeckB As HercEventCallbackHandler, ByVal userInstance As Integer) As Boolean

        Public Declare Function HERC_GetVersion Lib "HERC.dll" () As Integer

#End Region

    End Class

End Namespace
